==> anorack_0.2.7.orig.tar.gz: anorack-0.2.7/tests/test_open_file.py <==
# Copyright © 2016 Jakub Wilk <jwilk@jwilk.net>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the “Software”), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import os

from nose.tools import (
    assert_equal,
)

import lib.io as M

def t(path):
    encoding = 'ISO-8859-2'
    errors = 'xmlcharrefreplace'
    with M.open_file(path, encoding=encoding, errors=errors) as file:
        assert_equal(file.encoding, encoding)
        assert_equal(file.errors, errors)

def test_open_real_file():
    t(os.devnull)

def test_open_stdin():
    t('-')

# vim:ts=4 sts=4 sw=4 et

==> anorack_0.2.8.orig.tar.gz: anorack-0.2.8/tests/test_open_file.py <==
# Copyright © 2016-2021 Jakub Wilk <jwilk@jwilk.net>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the “Software”), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import os
import sys
import unittest

from tests.tools import (
    assert_equal,
    testcase,
)

import lib.io as M

def t(path):
    encoding = 'ISO-8859-2'
    errors = 'xmlcharrefreplace'
    with M.open_file(path, encoding=encoding, errors=errors) as file:
        assert_equal(file.encoding, encoding)
        assert_equal(file.errors, errors)

@testcase
def test_open_real_file():
    t(os.devnull)

@testcase
def test_open_stdin():
    with unittest.mock.patch('sys.stdin', sys.__stdin__):
        t('-')

del testcase

# vim:ts=4 sts=4 sw=4 et
